#ifndef MANAGEPRESETS_H
#define MANAGEPRESETS_H

#include <QDialog>
#include <QFile>
#include <QDir>
#include <QListWidget>

namespace Ui {
    class managepresets;
}

class managepresets : public QDialog
{
    Q_OBJECT

    friend class MainWindow;

public:
    explicit managepresets(QWidget *parent = 0);
    ~managepresets();

private:
    Ui::managepresets *ui;

private slots:
    void on_presetslist_currentRowChanged(int currentRow);
    void readpresets();
};

#endif // MANAGEPRESETS_H
